@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -79,8 +80,15 @@ void SAL_CALL typelib_typedescriptionreference_getByName(
  */
 struct AlignSize_Impl
 {
-    sal_Int16	nInt16;
-    double		dDouble;
+    sal_Int16 nInt16;
+#ifdef AIX
+    //double: doubleword aligned if -qalign=natural/-malign=natural
+    //which isn't the default ABI. Otherwise word aligned, While a long long int
+    //is always doubleword aligned, so use that instead.
+    sal_Int64   dDouble;
+#else
+    double dDouble;
+#endif
 };
 
 #ifdef SAL_W32
@@ -168,10 +176,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     OUString sTypeName( RTL_CONSTASCII_USTRINGPARAM("type") );
                     ::typelib_typedescriptionreference_new(
                         &s_aTypes[typelib_TypeClass_TYPE], typelib_TypeClass_TYPE, sTypeName.pData );
-#ifndef CPPU_LEAK_STATIC_DATA
-                    // another static ref
+                    // another static ref:
                     ++s_aTypes[typelib_TypeClass_TYPE]->nStaticRefCount;
-#endif
                 }
                 // any
                 if (! s_aTypes[typelib_TypeClass_ANY])
@@ -179,10 +185,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     OUString sTypeName( RTL_CONSTASCII_USTRINGPARAM("any") );
                     ::typelib_typedescriptionreference_new(
                         &s_aTypes[typelib_TypeClass_ANY], typelib_TypeClass_ANY, sTypeName.pData );
-#ifndef CPPU_LEAK_STATIC_DATA
-                    // another static ref
+                    // another static ref:
                     ++s_aTypes[typelib_TypeClass_ANY]->nStaticRefCount;
-#endif
                 }
                 // string
                 if (! s_aTypes[typelib_TypeClass_STRING])
@@ -190,10 +194,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     OUString sTypeName( RTL_CONSTASCII_USTRINGPARAM("string") );
                     ::typelib_typedescriptionreference_new(
                         &s_aTypes[typelib_TypeClass_STRING], typelib_TypeClass_STRING, sTypeName.pData );
-#ifndef CPPU_LEAK_STATIC_DATA
-                    // another static ref
+                    // another static ref:
                     ++s_aTypes[typelib_TypeClass_STRING]->nStaticRefCount;
-#endif
                 }
                 // XInterface
                 if (! s_aTypes[typelib_TypeClass_INTERFACE])
@@ -220,10 +222,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     ::typelib_typedescription_register( (typelib_TypeDescription **)&pTD );
                     ::typelib_typedescriptionreference_acquire(
                         s_aTypes[typelib_TypeClass_INTERFACE] = ((typelib_TypeDescription *)pTD)->pWeakRef );
-#ifndef CPPU_LEAK_STATIC_DATA
-                    // another static ref
+                    // another static ref:
                     ++s_aTypes[typelib_TypeClass_INTERFACE]->nStaticRefCount;
-#endif
                     ::typelib_typedescription_release( (typelib_TypeDescription*)pTD );
                     
                     ::typelib_typedescriptionreference_release( pMembers[0] );
@@ -252,10 +252,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     typelib_typedescription_register( &pTD1 );
                     typelib_typedescriptionreference_acquire(
                         s_aTypes[typelib_TypeClass_EXCEPTION] = pTD1->pWeakRef );
-#ifndef CPPU_LEAK_STATIC_DATA
-                    // another static ref
+                    // another static ref:
                     ++s_aTypes[typelib_TypeClass_EXCEPTION]->nStaticRefCount;
-#endif
                     // RuntimeException
                     OUString sTypeName2( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.uno.RuntimeException") );
                     ::typelib_typedescription_new(
@@ -263,7 +261,7 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
                     ::typelib_typedescription_register( &pTD1 );
                     ::typelib_typedescription_release( pTD1 );
                     }
-                    // XInterface members	
+                    // XInterface members
                     typelib_InterfaceMethodTypeDescription * pMethod = 0;
                     typelib_Parameter_Init aParameters[1];
                     OUString sParamName0( RTL_CONSTASCII_USTRINGPARAM("aType") );
@@ -302,10 +300,8 @@ typelib_TypeDescriptionReference ** SAL_CALL typelib_static_type_getByTypeClass(
             {
                 OUString aTypeName( OUString::createFromAscii( s_aTypeNames[eTypeClass] ) );
                 ::typelib_typedescriptionreference_new( &s_aTypes[eTypeClass], eTypeClass, aTypeName.pData );
-#ifndef CPPU_LEAK_STATIC_DATA
-                // another static ref
+                // another static ref:
                 ++s_aTypes[eTypeClass]->nStaticRefCount;
-#endif
             }
             }
         }
@@ -327,10 +323,8 @@ void SAL_CALL typelib_static_type_init(
             OUString aTypeName( OUString::createFromAscii( pTypeName ) );
             ::typelib_typedescriptionreference_new( ppRef, eTypeClass, aTypeName.pData );
             
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++((*ppRef)->nStaticRefCount);
-#endif
         }
     }
 }
@@ -364,10 +358,8 @@ void SAL_CALL typelib_static_sequence_type_init(
                 *ppRef = (typelib_TypeDescriptionReference *)pReg;
                 OSL_ASSERT( *ppRef == pReg->pWeakRef );
             }
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++((*ppRef)->nStaticRefCount);
-#endif
         }
     }
 }
@@ -450,10 +442,8 @@ void init(
                 *ppRef = (typelib_TypeDescriptionReference *)pReg;
                 OSL_ASSERT( *ppRef == pReg->pWeakRef );
             }
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++((*ppRef)->nStaticRefCount);
-#endif
         }
     }
 }
@@ -510,7 +500,7 @@ void SAL_CALL typelib_static_mi_interface_type_init(
             OUString aTypeName( OUString::createFromAscii( pTypeName ) );
             *ppRef = igetTypeByName( aTypeName.pData );
             if (!*ppRef)
-            {			
+            {
                 typelib_InterfaceTypeDescription * pIface = 0;
                 ::typelib_typedescription_newEmpty(
                     (typelib_TypeDescription **)&pIface, typelib_TypeClass_INTERFACE, aTypeName.pData );
@@ -551,10 +541,8 @@ void SAL_CALL typelib_static_mi_interface_type_init(
                 *ppRef = (typelib_TypeDescriptionReference *)pReg;
                 OSL_ASSERT( *ppRef == pReg->pWeakRef );
             }
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++((*ppRef)->nStaticRefCount);
-#endif
         }
     }
 }
@@ -593,10 +581,8 @@ void SAL_CALL typelib_static_enum_type_init(
                 *ppRef = (typelib_TypeDescriptionReference *)pReg;
                 OSL_ASSERT( *ppRef == pReg->pWeakRef );
             }
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++(*(sal_Int32 *)&(*ppRef)->pReserved);
-#endif
         }
     }
 }
@@ -660,10 +646,8 @@ void SAL_CALL typelib_static_array_type_init(
                 OSL_ASSERT( *ppRef == pReg->pWeakRef );
             } else
                 delete [] pDimensions;
-#ifndef CPPU_LEAK_STATIC_DATA
-            // another static ref
+            // another static ref:
             ++((*ppRef)->nStaticRefCount);
-#endif
         }
     }
 }
@@ -671,3 +655,5 @@ void SAL_CALL typelib_static_array_type_init(
 } // extern "C"
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
