@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -139,6 +140,7 @@ struct EnvironmentsData
     ::osl::Mutex mutex;
     OUString2EnvironmentMap aName2EnvMap;
 
+    EnvironmentsData() : isDisposing(false) {}
     ~EnvironmentsData();
 
     inline void getEnvironment(
@@ -147,6 +149,8 @@ struct EnvironmentsData
     inline void getRegisteredEnvironments(
         uno_Environment *** pppEnvs, sal_Int32 * pnLen,
         uno_memAlloc memAlloc, const OUString & rEnvDcp );
+
+    bool isDisposing;
 };
 
 namespace
@@ -595,9 +599,14 @@ static void SAL_CALL defenv_harden(
         *ppHardEnv = 0;
     }
 
+    EnvironmentsData & rData = theEnvironmentsData::get();
+
+    if (rData.isDisposing)
+        return;
+
     uno_DefaultEnvironment * that = (uno_DefaultEnvironment *)pEnv;
     {
-    ::osl::MutexGuard guard( theEnvironmentsData::get().mutex );
+    ::osl::MutexGuard guard( rData.mutex );
     if (1 == ::osl_incrementInterlockedCount( &that->nRef )) // is dead
     {
         that->nRef = 0;
@@ -914,6 +923,7 @@ static void SAL_CALL unoenv_releaseInterface(
 EnvironmentsData::~EnvironmentsData()
 {
     ::osl::MutexGuard guard( mutex );
+    isDisposing = true;
 
     for ( OUString2EnvironmentMap::const_iterator iPos( aName2EnvMap.begin() );
           iPos != aName2EnvMap.end(); ++iPos )
@@ -928,11 +938,7 @@ EnvironmentsData::~EnvironmentsData()
 #if OSL_DEBUG_LEVEL > 1
             ::uno_dumpEnvironment( 0, pHard, 0 );
 #endif
-#if defined CPPU_LEAK_STATIC_DATA
-            pHard->environmentDisposing = 0; // set to null => wont be called
-#else
             (*pHard->dispose)( pHard ); // send explicit dispose
-#endif
             (*pHard->release)( pHard );
         }
     }
@@ -1180,3 +1186,4 @@ void SAL_CALL uno_getRegisteredEnvironments(
 
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
