@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -499,23 +500,6 @@ int SAL_CALL main (int argc, char **argv)
             "t_store::main(): store_createDirectory() failed");
         if (eErrCode == store_E_None)
         {
-#if 0  /* NYI */
-            // Rename directory.
-            eErrCode = aFile.rename (
-                aPath, "demostor-1.dir/",
-                aPath, "Renamed demostor-1.dir");
-            OSL_POSTCOND(
-                ((eErrCode == store_E_None         ) ||
-                 (eErrCode == store_E_AlreadyExists)    ),
-                "t_store::main(): store_rename() failed");
-
-            eErrCode = aFile.rename (
-                aPath, "Renamed demostor-1.dir/",
-                aPath, "demostor-1.dir");
-            OSL_POSTCOND(
-                (eErrCode == store_E_None),
-                "t_store::main(): store_rename() failed");
-#endif  /* NYI */
         }
     }
 
@@ -603,3 +587,5 @@ int SAL_CALL main (int argc, char **argv)
 
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
